@@ -6,12 +6,14 @@ from PyQt5 import QtGui
 from PyQt5 import QtPrintSupport
 from rawprasslib import load_raw
 from prasopes.predictmz import predict as getmzpattern
+from pathlib import Path
 try:
     from rawautoparams import load_params
     import rawautoparams
     autoparams = True
 except ImportError:
     autoparams = False
+import copy
 import rawprasslib
 import numpy as np
 import prasopes.config as cf
@@ -22,6 +24,8 @@ import prasopes.graphtools as gt
 import prasopes.imagetools as imgt
 import prasopes.zcetools as zce
 import prasopes.docks as docks
+import prasopes.datasets as datasets
+import prasopes.toftools as tt
 import prasopes.tangoicons
 import sys
 import logging
@@ -61,12 +65,15 @@ def show_exception_and_exit(exc_type, exc_value, tb):
         sys.exit(-1)
 
 
-def load_file(parent, augCanvas, update, settings, loadthread, filename=None):
+def load_file(parent, augCanvas, update, settings, loadthread, filename=None,
+              nothreading=False):
     """populates dataset and plots it"""
-    directory = augCanvas.filename or settings.value("open_folder")
+    directory = augCanvas.ds.filename if augCanvas.ds\
+                else settings.value("open_folder")
     filename = filename or QtWidgets.QFileDialog.getOpenFileName(
             caption="Open spectrum", directory=directory,
-            filter="Finnigan RAW files (*.raw, *.RAW)")[0]
+            filter="All supported formats (*.raw *.RAW *.d);;"
+                   "Finnigan RAW files (*.raw *.RAW);;timsTOF file (*.d)")[0]
     if filename != '' and os.path.isfile(filename)\
             and not os.path.isdir(filename):
         error = update_signal()
@@ -74,12 +81,9 @@ def load_file(parent, augCanvas, update, settings, loadthread, filename=None):
 
         def runfnc():
             try:
-                [i.clear() for i in (
-                    augCanvas.ds, augCanvas.chrom['timesarg'],
-                    augCanvas.ms['params'], augCanvas.ms['headers'])]
-                [augCanvas.ds.append(dict(
-                    chrom_dat=i[0], masses=i[1], matrix=i[2]))
-                 for i in load_raw(filename, settings.value("tmp_location"))]
+                augCanvas.ds = datasets.ThermoRawDataset(filename) if\
+                        os.path.splitext(filename)[1] in (".raw", ".RAW")\
+                        else datasets.BrukerTimsDataset(filename)
             except rawprasslib.ParsingException as pex:
                 errormsg.append("Opening of the file has failed!")
                 errormsg.append(
@@ -88,34 +92,18 @@ def load_file(parent, augCanvas, update, settings, loadthread, filename=None):
                     "Error message:\n{}".format(pex.args[0]))
                 error.signal.emit()
                 return
-            if autoparams:
-                try:
-                    (augCanvas.ms['params'], rawheaders,
-                        augCanvas.chrom['machtype']) = load_params(
-                                filename, settings.value("tmp_location"))
-                    segments = [len(subset['chrom_dat'][0])
-                                for subset in augCanvas.ds]
-                    indicies = [sum(segments[:i+1])
-                                for i in range(len(segments))]
-                    augCanvas.ms['headers'] = np.split(
-                            rawheaders, indicies)[:-1]
-                except Exception as pex:
-                    errormsg.append(
-                            "File is incompatible with the rawautoparams,")
-                    errormsg.append(
-                            "no parameters loaded!\n\n"
-                            "Error message:\n{}".format(pex.args[0]))
-                    error.signal.emit()
             gt.populate(augCanvas)
-            augCanvas.filename = filename
             oldrecents = settings.value("recents")
             oldrecents.remove(filename) if filename in oldrecents else None
-            settings.setValue("recents", [filename, *oldrecents])
+            settings.setValue("recents", [filename, *oldrecents][:10])
             update.signal.emit()
         error.signal.connect(lambda: QtWidgets.QMessageBox.critical(
             parent, errormsg[0], errormsg[1]))
-        loadthread.run = runfnc
-        loadthread.start()
+        if nothreading:
+            runfnc()
+        else:
+            loadthread.run = runfnc
+            loadthread.start()
 
 
 def print_graph(augCanvas):
@@ -142,36 +130,19 @@ def print_graph(augCanvas):
     printer = printPreview.printer()
     printer.setPageSize(printer.A5)
     printer.setDuplex(printer.DuplexNone)
-    image = imgt.paint_image(augCanvas.ms, augCanvas.spectplot,
-                             augCanvas.filename, printer)
+    imggen = imgt.ImagePainter("msspec", printer)
+    imggen.popfig = lambda: paint_override(imggen, augCanvas)
+    image = imggen.paint()
     printPreview.paintRequested.connect(lambda:
                                         printimage(printer, image))
     printPreview.exec()
 
 
 def update_spectrum(augCanvas, config):
-    if augCanvas.filename:
+    if augCanvas.ds:
         slims = [augCanvas.spectplot.get_xlim(),
                  augCanvas.spectplot.get_ylim()]
-        augCanvas.ds.clear()
-        [augCanvas.ds.append(dict(chrom_dat=i[0], masses=i[1], matrix=i[2]))
-         for i in load_raw(augCanvas.filename, config.value("tmp_location"))]
-        if autoparams:
-            try:
-                (augCanvas.ms['params'], rawheaders,
-                    augCanvas.chrom['machtype']) = load_params(
-                            augCanvas.filename, config.value("tmp_location"))
-                segments = [len(subset['chrom_dat'][0])
-                            for subset in augCanvas.ds]
-                indicies = [sum(segments[:i+1])
-                            for i in range(len(segments))]
-                augCanvas.ms['headers'] = np.split(
-                        rawheaders, indicies)[:-1]
-            except Exception as pex:
-                QtWidgets.QMessageBox.critical(None,
-                        "File is incompatible with the rawautoparams",
-                        "no parameters loaded!\n\n"
-                        "Error message:\n{}".format(pex))
+        augCanvas.ds.refresh()
         gt.populate(augCanvas)
         augCanvas.spectplot.set_xlim(slims[0])
         augCanvas.spectplot.set_ylim(slims[1])
@@ -222,22 +193,56 @@ def predictmz(form, augCanvas):
 
 
 def oddeven_changed(augCanvas, config, oddevenact):
+    print("trigd")
     config.setValue("view/oddeven", oddevenact.isChecked())
     update_spectrum(augCanvas, config)
 
 
+def legendvis_changed(augCanvas, config, legendact):
+    config.setValue("view/legend",legendact.isChecked())
+    if augCanvas.chromplot.get_legend():
+        for ax in (augCanvas.spectplot, augCanvas.chromplot):
+            ax.get_legend().set_visible(config.value("view/legend", type=bool))
+        augCanvas.draw()
+
+
+def paint_override(self, augCanvas):
+    self.plot.set_xlim(augCanvas.spectplot.get_xlim())
+    self.plot.set_ylim(augCanvas.spectplot.get_ylim())
+    data = [line.get_data() for line in augCanvas.spectplot.lines]
+    texts = copy.copy(augCanvas.ms)
+    if augCanvas.ds and augCanvas.ds.headers:
+        legend = augCanvas.spectplot.get_legend().get_texts()
+        [gt.pop_plot(*line, self.plot, texts, i, legend[i].get_text(),
+                     not (cf.settings().value(
+                         self.conftype.format("onlymanann"), type=bool)))
+            for i, line in enumerate(data)]
+        legend = 1
+        if legend == True:
+            self.plot.legend(loc=2)
+    else:
+        [gt.pop_plot(*line, self.plot, texts, i)
+            for i, line in enumerate(data)]
+    xtics = int(cf.settings().value(self.conftype.format("xtics")))
+    self.plot.locator_params(nbins=xtics, axis='x')
+    if augCanvas.ds:
+        self.plot.set_title(Path(
+            *Path(augCanvas.ds.filename).resolve().parts[-2:]), loc="right")
+
+
 def key_pressed(event, augCanvas, config, update):
     if event.key() == QtCore.Qt.Key_F5:
         update_spectrum(augCanvas, config)
-        if augCanvas.filename:
+        if augCanvas.ds:
             update.signal.emit()
     if event.key() == QtCore.Qt.Key_C:
         if event.modifiers().__int__() == QtCore.Qt.ControlModifier:
             if augCanvas.paramstable.underMouse():
                 dt.clip_tablestr(augCanvas)
             else:
-                imgt.clip_spect_img(augCanvas.ms, augCanvas.spectplot,
-                                    augCanvas.filename)
+                painter = imgt.ImagePainter("msspec")
+                painter.popfig = lambda: paint_override(painter, augCanvas)
+                painter.clip()
         if event.modifiers().__int__() == QtCore.Qt.ControlModifier + \
                 QtCore.Qt.ShiftModifier:
             dt.clip_spectstr(augCanvas)
@@ -280,9 +285,13 @@ def main():
     drl_logger = logging.getLogger('drlLogger')
     zce_logger = logging.getLogger('zcelogger')
     rxn_logger = logging.getLogger('reactivityLogger')
+    ds_logger = logging.getLogger('dsLogger')
+    toflogger = logging.getLogger('tofLogger')
+    toflogger.setLevel("DEBUG")
     logging.basicConfig()
     # p_logger.setLevel("WARN")
     p_logger.setLevel("DEBUG")
+    ds_logger.setLevel("DEBUG")
     rxn_logger.setLevel("DEBUG")
     # drl_logger.setLevel("INFO")
     drl_logger.setLevel("DEBUG")
@@ -295,7 +304,7 @@ def main():
 
     main_window = QtWidgets.QMainWindow(windowTitle="Prasopes")
     update.signal.connect(lambda: main_window.setWindowTitle(
-        "Prasopes - {}".format(os.path.basename(augCanvas.filename))))
+        "Prasopes - {}".format(os.path.basename(augCanvas.ds.filename))))
 
     if QtGui.QIcon.themeName() == "":
         QtGui.QIcon.setThemeName("TangoMFK")
@@ -341,6 +350,11 @@ def main():
     drlact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_D)
     drlact.triggered.connect(lambda: drlgui.main_window(
         main_window, augCanvas, update))
+    tofact = QtWidgets.QAction(QtGui.QIcon.fromTheme(
+        "applications-utilities"), "TO&F...", None)
+    tofact.setShortcut(QtCore.Qt.CTRL + QtCore.Qt.Key_F)
+    tofact.triggered.connect(lambda: tt.main_window(
+        main_window, augCanvas, update))
     aboutact = QtWidgets.QAction("&About Prasopes", None)
     aboutact.triggered.connect(lambda: about(main_window))
     autozoomy = QtWidgets.QAction(QtGui.QIcon.fromTheme(
@@ -357,6 +371,11 @@ def main():
     intensitiesact.triggered.connect(lambda: gt.ann_spec(
         augCanvas.spectplot, augCanvas.ms))
     intensitiesact.triggered.connect(lambda: augCanvas.draw())
+    legendact = QtWidgets.QAction(
+        "&Show legend", None, checkable=True,
+        checked=config.value("view/legend", type=bool))
+    legendact.triggered.connect(lambda: legendvis_changed(
+        augCanvas, config, legendact))
     oddevenact = QtWidgets.QAction(
             "&Odd / even", None, checkable=True,
             checked=config.value("view/oddeven", type=bool))
@@ -388,11 +407,12 @@ def main():
     main_window.menuBar().addMenu(tools_menu)
     tools_menu.addAction(zceact)
     tools_menu.addAction(drlact)
+    tools_menu.addAction(tofact)
     tools_menu.addSeparator()
     view_menu = QtWidgets.QMenu('&View', main_window)
     [view_menu.addAction(i.action) for i in
      (treedock, paramsdock, consoledock)]
-    [view_menu.addAction(i) for i in (autozoomy, intensitiesact)]
+    [view_menu.addAction(i) for i in (autozoomy, intensitiesact, legendact)]
     view_menu.addSeparator()
     view_menu.addAction(oddevenact)
     main_window.menuBar().addMenu(view_menu)
@@ -416,6 +436,7 @@ def main():
     toolBar.addSeparator()
     toolBar.addAction(zceact)
     toolBar.addAction(drlact)
+    toolBar.addAction(tofact)
     toolBar.addSeparator()
     toolBar.addAction(autozoomy)
 
@@ -438,7 +459,7 @@ def main():
 
     if len(sys.argv) == 2:
         load_file(main_window, augCanvas, update, config, loadthread,
-                  filename=sys.argv[1])
+                  filename=sys.argv[1], nothreading=True)
     else:
         gt.pop_plot([], [], augCanvas.spectplot, augCanvas.ms)
         gt.pop_plot([], [], augCanvas.chromplot, augCanvas.chrom)
