@@ -12,17 +12,38 @@ def settings():
                ("view/acqparvisible", True),
                ("view/intensities", False),
                ("view/oddeven", False),
-               ("print/xinch", 10),
-               ("print/yinch", 4),
-               ("print/dpi", 300),
-               ("print/xtics", 5),
-               ("imggen/xinch", 10),
-               ("imggen/yinch", 4),
-               ("imggen/dpi", 300),
-               ("imggen/xtics", 5),
-               ("imggen/onlymanann", False),
+               ("view/legend", True),
+               ("print/msspec_xinch", 10),
+               ("print/msspec_yinch", 4),
+               ("print/msspec_dpi", 300),
+               ("print/msspec_xtics", 5),
+               ("print/zcespec_xinch", 5),
+               ("print/zcespec_yinch", 2),
+               ("print/zcespec_dpi", 300),
+               ("print/reactspecspec_xinch", 3.5),
+               ("print/reactspecspec_yinch", 2),
+               ("print/reactspecspec_dpi", 300),
+               ("imggen/msspec_xinch", 10),
+               ("imggen/msspec_yinch", 4),
+               ("imggen/msspec_dpi", 300),
+               ("imggen/msspec_xtics", 5),
+               ("imggen/msspec_onlymanann", False),
+               ("imggen/zcespec_xinch", 5),
+               ("imggen/zcespec_yinch", 2),
+               ("imggen/zcespec_dpi", 300),
+               ("imggen/drlspec_xinch", 10),
+               ("imggen/drlspec_yinch", 4),
+               ("imggen/drlspec_dpi", 300),
+               ("imggen/reactspecspec_xinch", 3.5),
+               ("imggen/reactspecspec_yinch", 2),
+               ("imggen/reactspecspec_dpi", 300),
                ("reactivity/index", 0),
-               ("recents", "")}
+               ("reactivity/activetab", 0),
+               ("recents", ""),
+               ("timstof/ms_sampling", 500),
+               ("timstof/ms_bins", 0.001),
+               ("timstof/mob_sampling", 5000),
+               ("timstof/mob_bins", 0.0001)}
     [settings.setValue(*i)
      for i in defvals if not settings.contains(i[0])]
     return settings
@@ -107,17 +128,30 @@ def dial(parent):
     imggentab = QtWidgets.QWidget()
     imggenlayout = QtWidgets.QVBoxLayout(imggentab)
     imggenlayout.addLayout(posvarconf(
-        "Figure width (inch)", "imggen/xinch", config, "nonint"))
+        "Figure width (inch)", "imggen/msspec_xinch", config, "nonint"))
     imggenlayout.addLayout(posvarconf(
-        "Figure height (inch)", "imggen/yinch", config, "nonint"))
+        "Figure height (inch)", "imggen/msspec_yinch", config, "nonint"))
     imggenlayout.addLayout(posvarconf(
-        "Figure dpi", "imggen/dpi", config))
+        "Figure dpi", "imggen/msspec_dpi", config))
     imggenlayout.addLayout(posvarconf(
-        "Figure x axis major ticks count", "imggen/xtics", config))
+        "Figure x axis major ticks count", "imggen/msspec_xtics", config))
     imggenlayout.addWidget(checkboxconf(
-        "Manual annotation only", "imggen/onlymanann", config))
+        "Manual annotation only", "imggen/msspec_onlymanann", config))
     tabs.addTab(imggentab, "Image clip/export")
 
+    timstoftab = QtWidgets.QWidget()
+    timstoflayout = QtWidgets.QVBoxLayout(timstoftab)
+    timstoflayout.addLayout(posvarconf(
+        "Maximum number of samples - MS", "timstof/ms_sampling", config))
+    timstoflayout.addLayout(posvarconf(
+        "Bins - MS", "timstof/ms_bins", config, "nonint"))
+    timstoflayout.addLayout(posvarconf(
+        "Maximum number of samples - mobility", "timstof/mob_sampling", config))
+    timstoflayout.addLayout(posvarconf(
+        "Bins - mobility", "timstof/mob_bins", config, "nonint"))
+    tabs.addTab(timstoftab, "timsTOF")
+
+
     close_button = QtWidgets.QPushButton("Close")
     close_button.clicked.connect(dialog.close)
 
