@@ -17,9 +17,8 @@ def argsubselect(array, minimum, maximum):
 
 def specttostr(augCanvas, delim=" ", names=["mass","ion_count"], units=["m/z",""], description = ""):
     lines = augCanvas.get_lines()
-    setnum = len(lines)
-    formnames = delim.join([delim.join(names) for i in range(setnum)])
-    formunits = (delim).join([delim.join(units) for i in range(setnum)])
+    formnames = delim.join([delim.join(names) for i in range(len(lines))])
+    formunits = (delim).join([delim.join(units) for i in range(len(lines))])
     header = "\n".join([formnames, formunits, description])+"\n"
 
     strdata = []
@@ -36,8 +35,8 @@ def specttostr(augCanvas, delim=" ", names=["mass","ion_count"], units=["m/z",""
 
 def clip_spectstr(augCanvas):
     description = ("{}_{:.4}-{:.4}_minutes_of_the_aquisition".format(
-                   os.path.basename(augCanvas.filename),
-                   augCanvas.chrom['t_start'], augCanvas.chrom['t_end']))
+                   os.path.basename(augCanvas.ds.filename),
+                   augCanvas.ds.mintime, augCanvas.ds.maxtime))
     string = specttostr(augCanvas.spectplot, delim="\t", description=description)
     QtWidgets.QApplication.clipboard().clear()
     [QtWidgets.QApplication.clipboard().setText(string, i) for i in range(2)]
