@@ -6,6 +6,7 @@ from PyQt5 import QtCore
 from PyQt5 import QtWidgets
 from PyQt5 import QtGui
 from PyQt5 import QtPrintSupport
+from prasopes.datasets import ThermoRawDataset
 import matplotlib
 import numpy as np
 import prasopes.datatools as dt
@@ -14,6 +15,7 @@ import prasopes.filetools as ft
 import prasopes.config as cf
 import prasopes.reactivitytools as rt
 import prasopes.drltools as drl
+import prasopes.imagetools as imgt
 import os.path
 import logging
 matplotlib.use("Qt5Agg")
@@ -35,22 +37,23 @@ def update_profile(pt, row, dataset):
     """parent table profile spectrum updating procedure"""
     logger.debug("updating parent table row {} profile".format(row))
     # Dont do anything to graph when the spectrum is not populated
-    if len(dataset) == 0:
+    if not dataset:
         return
     spectrum = pt.cellWidget(row, 3).figure.get_axes()[0]
     spectrum.clear()
     limits = []
-    for i, subset in enumerate(dataset):
-        masses = subset['masses']
-        massargs = drl.get_massargs(pt, row, subset)
-        yshape = np.mean(subset['matrix'], axis=0)
-        spectrum.plot(masses, yshape, ':', color='gray')
-        spectrum.plot(masses[massargs], yshape[massargs], color=gt.colors[
-            i % len(gt.colors)]/255)
-        limits.append((masses[massargs[[0, -1]]], max(yshape[massargs])))
+    spectra = dataset.get_spectra(-np.inf, np.inf)
+    for i,spectxy in enumerate(spectra):
+        massargs = drl.get_massargs(pt, row, spectxy[0])
+        spectrum.plot(spectxy[0], spectxy[1], ':', color='gray')
+        spectrum.plot(spectxy[0][massargs], spectxy[1][massargs],
+                      color=gt.colors[i % len(gt.colors)]/255)
+        limits.append((spectxy[0][massargs[[0, -1]]],
+                       max(spectxy[1][massargs])))
     widest = np.argmax([abs(lim[0][1]-lim[0][0]) for lim in limits])
     xmin, xmax = limits[widest][0]
-    xex = max((xmax-xmin)*0.25, 0.20)
+    xexlim = 0.20 if type(dataset) == ThermoRawDataset else 0.02
+    xex = max((xmax-xmin)*0.25, xexlim)
     spectrum.set_xlim(xmin-xex, xmax+xex)
     ymax = max(*[lim[1] for lim in limits], 1)
     spectrum.set_ylim(ymax*-0.1, ymax*1.2)
@@ -61,7 +64,7 @@ def update_drlspectrum(ds, drls, drlspectrum):
     """Generic DRL spectrum updating procedure"""
     logger.info("updating DRL spectrum")
     # Do not do anything when the data set is not populated.
-    if len(ds) == 0:
+    if not ds:
         return
 
     names, times, intensities = drl.get_daughterset(ds, drls)
@@ -352,8 +355,8 @@ def save_drlconfig(drls, parent, exp_f_name=None):
         expf.close()
 
 
-def export_drlspectrum(parent, fn, ds, drls):
-    if fn[0] is None:
+def export_drlspectrum(parent, ds, drls):
+    if not ds:
         QtWidgets.QMessageBox.warning(
             None, "Export DRL dat aset",
             "No file opened. Nothing to export, canceling request")
@@ -377,7 +380,7 @@ def export_drlspectrum(parent, fn, ds, drls):
             None, "Export DRL data", options=(
                 QtWidgets.QFileDialog.DontConfirmOverwrite |
                 QtWidgets.QFileDialog.HideNameFilterDetails),
-            directory=fn[0][:-4])[0]
+            directory=ds.filename[0][:-4])[0]
     if fname == '':
         return
     exp_f_name = list(map(lambda x: "{}/{}-{}.csv".format(
@@ -486,6 +489,12 @@ def paste_clip(ds, drls, drlspectrum):
                         and i < table.rowCount():
                     table.item(i, j).setText(col)
 
+def paint_override(self, ds, drls, drlspectrum):
+    update_drlspectrum(ds, drls, self.plot)
+    self.plot.set_xlim(drlspectrum.get_xlim())
+    self.plot.set_ylim(drlspectrum.get_ylim())
+    self.plot.figure.canvas.draw()
+
 
 def key_pressed(event, ds, drls, drlspectrum):
     if event.key() == QtCore.Qt.Key_Delete:
@@ -498,7 +507,13 @@ def key_pressed(event, ds, drls, drlspectrum):
             update_profile(drls['pt'], row, ds)
     if event.key() == QtCore.Qt.Key_C\
             and event.modifiers().__int__() == QtCore.Qt.ControlModifier:
-        clip_range(drls)
+        if drls['dt'].underMouse() or drls['pt'].underMouse():
+            clip_range(drls)
+        else:
+            imggen = imgt.ImagePainter("drlspec")
+            imggen.popfig = lambda: paint_override(
+                    imggen, ds, drls, drlspectrum)
+            imggen.clip()
     if event.key() == QtCore.Qt.Key_V\
             and event.modifiers().__int__() == QtCore.Qt.ControlModifier:
         paste_clip(ds, drls, drlspectrum)
@@ -530,7 +545,6 @@ def select_all_btn_up(ds, drls, drlspectrum, state=None):
 def main_window(parent, augCanvas, update_signal):
     """constructs a dialog window"""
     ds = augCanvas.ds
-    filename = augCanvas.filename
     cache = augCanvas.drlcache
 
     def onclose(widget, event, buffer, drls,
@@ -579,7 +593,7 @@ def main_window(parent, augCanvas, update_signal):
             dcolums.append("factor ({})".format(i+1))
         drls['dt'] = dt.table(dcolums)
         drls['pt'] = dt.table(["Name", "Mass (m/z)", "Peak width",
-                               "profile"])
+                               "Profile"])
         # TODO: DIRTY, DIRTY, DIRTY !!! Do it nicer when I'll know how
         [drls['dt'].horizontalHeader().setSectionResizeMode(
              n, QtWidgets.QHeaderView.Interactive) for n in range(
@@ -625,7 +639,7 @@ def main_window(parent, augCanvas, update_signal):
         drls, main_widget))
     drl_print.clicked.connect(lambda: print_graph(ds, drls))
     drl_export.clicked.connect(lambda: export_drlspectrum(
-        main_widget, filename, ds, drls))
+        main_widget, ds, drls))
     drl_reactivity.clicked.connect(lambda: rt.main_window(parent,
         augCanvas, update_signal, drls))
 
