@@ -26,16 +26,15 @@ class AugFigureCanvas(FigureCanvas):
         self.figure = Figure(figsize=(5, 4), dpi=100, facecolor="None",
                              constrained_layout=True)
         super().__init__(self.figure)
-        self.ds = []
+        self.ds = None
         self.ms = dict(annotation=[], name="Spectrum", xlabel="m/z",
-                       ylabel="ion count", xtics=20, predict=None,
-                       params=[], headers=[], texts=[])
+                       ylabel="ion count", xtics=20, predict=None, texts=[])
         self.chrom = dict(
             x=[0], y=[0], t_start=None, t_end=None, machtype=None,
             name="Chromatogram", xlabel="time(min)", ylabel="total ion count",
             timesarg=[])
-        self.filename = None
         self.drlcache = [None, None]
+        self.tofcache = [None, None]
         grid = self.figure.add_gridspec(2, 1)
         self.chromplot = self.figure.add_subplot(grid[0, 0],
                                                  facecolor=(1, 1, 1, 0.8))
@@ -238,74 +237,38 @@ def plot_subtime(augCanvas):
     augCanvas.spectplot.clear()
     augCanvas.chromplot.clear()
 
-    for i, subset in enumerate(augCanvas.ds):
-        selection = augCanvas.chrom['timesarg'][i]
-        if len(augCanvas.ms['headers']) == len(augCanvas.ds):
-            legend = legendize(augCanvas.ms['headers'][i][selection],
-                               augCanvas.chrom)
-        else:
-            legend = None
-        if cf.settings().value("view/oddeven", type=bool):
-            for j in range(2):
-                chromx = subset['chrom_dat'][0, :][j::2]
-                chromy = subset['chrom_dat'][1, :][j::2]
-                pop_plot(chromx, chromy, augCanvas.chromplot,
-                         augCanvas.chrom, i*2+j, legend)
-                if not np.array_equal(selection[j::2], []):
-                    clr = i*2+j if selection[0] % 2 == 0\
-                            else i*2+(1-j)
-                    ms_x = subset['masses']
-                    ms_y = np.mean(subset['matrix'][selection[j::2]], axis=0)
-                    pop_plot(ms_x, ms_y, augCanvas.spectplot,
-                             augCanvas.ms, clr, legend)
-                    dots_x = subset['chrom_dat'][0, selection[j::2]]
-                    dots_y = subset['chrom_dat'][1, selection[j::2]]
-                    augCanvas.chromplot.plot(dots_x, dots_y, '.', color=(
-                        colors[(clr) % len(colors)]/255))
-        else:
-            chromx = subset['chrom_dat'][0, :]
-            chromy = subset['chrom_dat'][1, :]
-            pop_plot(chromx, chromy, augCanvas.chromplot,
-                     augCanvas.chrom, i, legend)
-            if not np.array_equal(selection, []):
-                ms_x = subset['masses']
-                ms_y = np.mean(subset['matrix'][selection], axis=0)
-                pop_plot(ms_x, ms_y, augCanvas.spectplot,
-                         augCanvas.ms, i, legend)
-                dots_x = subset['chrom_dat'][0, selection]
-                dots_y = subset['chrom_dat'][1, selection]
-                augCanvas.chromplot.plot(dots_x, dots_y, '.', color=(
-                    colors[i % len(colors)]/255))
+    chromargs = augCanvas.ds.get_chromargs()
+    populate(augCanvas)
+
+    for i, args in enumerate(chromargs):
+        if len(args):
+            dots_x, dots_y = [augCanvas.ds.chromatograms[i][j][args]
+                              for j in (0,1)]
+            augCanvas.chromplot.plot(dots_x, dots_y, '.', color=(
+            colors[i % len(colors)]/255))
 
     augCanvas.spectplot.set_xlim(slims[0])
     if not cf.settings().value("view/autozoomy", type=bool):
         augCanvas.spectplot.set_ylim(slims[1])
-    if not augCanvas.ms['headers'] == []:
-        augCanvas.spectplot.legend(loc=2)
-        augCanvas.spectplot.get_legend().set_in_layout(False)
-        augCanvas.chromplot.legend(loc=2)
-        augCanvas.chromplot.get_legend().set_in_layout(False)
+    if augCanvas.ds.headers:
+        for ax in (augCanvas.spectplot, augCanvas.chromplot):
+            ax.legend(loc=2)
+            ax.get_legend().set_in_layout(False)
+            ax.get_legend().set_visible(
+                    cf.settings().value("view/legend", type=bool))
     else:
         autozoomy(augCanvas.spectplot)
     ann_spec(augCanvas.spectplot, augCanvas.ms)
     augCanvas.chromplot.set_xlim(chlims[0])
     augCanvas.chromplot.set_ylim(chlims[1])
     augCanvas.draw()
+    update_paramstable(augCanvas)
 
 
 def pick_times(x_min, x_max, augCanvas):
     """subselect part of the chromatogram and plot it"""
-    augCanvas.chrom['t_start'] = x_min
-    augCanvas.chrom['t_end'] = x_max
-    times = dt.argsubselect(np.concatenate(
-        [subset['chrom_dat'][0] for subset in augCanvas.ds]), x_min, x_max)
-    augCanvas.chrom['timesarg'].clear()
-    for subset in augCanvas.ds:
-        goodtimes = np.where((times < len(subset['chrom_dat'][0]))
-                             & ~(times < 0))[0]
-        augCanvas.chrom['timesarg'].append(times[goodtimes])
-        times = times - len(subset['chrom_dat'][0])
-    update_paramstable(augCanvas)
+    augCanvas.ds.mintime = x_min
+    augCanvas.ds.maxtime = x_max
     plot_subtime(augCanvas)
 
 
@@ -429,7 +392,7 @@ def pop_plot(xdata, ydata, plot, plot_data, colornum=0, legend=None, annotate=Tr
         plot.tick_params(axis='y', which='minor', left=False)
 
 
-def legendize(rawlegend, chrom_data):
+def legendize(rawlegend, augCanvas):
     # sanity check
     if len(rawlegend) == 0:
         return None
@@ -437,14 +400,14 @@ def legendize(rawlegend, chrom_data):
     quads = ["q3", "q1"]
 
     def translate(wut):
-        if chrom_data['machtype'] == 47:
+        if augCanvas.ds.machtype == 47:
             if wut[1] in (0, 1):
                 text = "{}{}ms; m/z = {:.1f}-{:.1f}".format(
                         marks[int(wut[0])], quads[int(wut[1])], *wut[4:])
             else:
                 text = "{}ms^{} {:.2f}@{:.1f}V; m/z = {:.1f}-{:.1f}".format(
                         marks[int(wut[0])], *wut[1:])
-        elif chrom_data['machtype'] in (57, 63):
+        elif augCanvas.ds.machtype in (57, 63):
             if int(wut[1]) == 1:
                 text = "{}ms; m/z = {:.1f}-{:.1f}".format(
                         marks[int(wut[0])], *wut[2:])
@@ -461,7 +424,7 @@ def legendize(rawlegend, chrom_data):
         np.unique(np.array(rawlegend), axis=0, return_index=True)
     strdata = [translate(i) for i in rawlegend[np.sort(uniqindexs[1])]]
     strtext = " and\n".join(strdata) + "; t = {:.2f}-{:.2f} min".format(
-                    chrom_data['t_start'], chrom_data['t_end'])
+                    augCanvas.ds.mintime, augCanvas.ds.maxtime)
     return strtext
 
 
@@ -485,35 +448,23 @@ def populate(augCanvas):
         [pints.extend([np.nan, 0, i]) for i in crudeints]
         augCanvas.spectplot.plot(pmasses, pints, linewidth=1)
 
-    augCanvas.chrom['t_start'] = augCanvas.ds[0]['chrom_dat'][0, 0]
-    augCanvas.chrom['t_end'] = augCanvas.ds[-1]['chrom_dat'][0, -1]
-    for i, subset in enumerate(augCanvas.ds):
-        if len(augCanvas.ms['headers']) == len(augCanvas.ds):
-            legend = legendize(augCanvas.ms['headers'][i], augCanvas.chrom)
+    chromxy = augCanvas.ds.chromatograms
+    msxy = augCanvas.ds.get_spectra()
+    for i in range(len(msxy)):
+        if augCanvas.ds.headers and\
+                len(augCanvas.ds.headers) == len(augCanvas.ds.chromatograms):
+            legend = legendize(augCanvas.ds.headers[i], augCanvas)
         else:
             legend = None
-        if cf.settings().value("view/oddeven", type=bool):
-            msx = subset['masses']
-            for j in range(2):
-                msy = np.mean(subset['matrix'][j::2], axis=0)
-                chromx = subset['chrom_dat'][0, :][j::2]
-                chromy = subset['chrom_dat'][1, :][j::2]
-                pop_plot(msx, msy, augCanvas.spectplot, augCanvas.ms,
-                         i*2+j, legend)
-                pop_plot(chromx, chromy, augCanvas.chromplot,
-                         augCanvas.chrom, i*2+j, legend)
-        else:
-            msx = subset['masses']
-            msy = np.mean(subset['matrix'], axis=0)
-            chromx = subset['chrom_dat'][0, :]
-            chromy = subset['chrom_dat'][1, :]
-            pop_plot(msx, msy, augCanvas.spectplot, augCanvas.ms, i, legend)
-            pop_plot(chromx, chromy, augCanvas.chromplot, augCanvas.chrom,
-                     i, legend)
+        pop_plot(msxy[i][0], msxy[i][1], augCanvas.spectplot, augCanvas.ms, i, legend)
+        pop_plot(chromxy[i][0], chromxy[i][1], augCanvas.chromplot,
+                augCanvas.chrom, i, legend)
     for ax in (augCanvas.spectplot, augCanvas.chromplot):
-        if not augCanvas.ms['headers'] == []:
+        if augCanvas.ds.headers:
             ax.legend(loc=2)
             ax.get_legend().set_in_layout(False)
+            ax.get_legend().set_visible(
+                    cf.settings().value("view/legend", type=bool))
         ax.autoscale(True)
         ax.set_ylim(ax.get_ylim()[1]*-0.01, ax.get_ylim()[1]*1.1)
     augCanvas.constrained_draw()
@@ -521,25 +472,25 @@ def populate(augCanvas):
 
 
 def update_paramstable(augCanvas):
-    if len(augCanvas.ms['params']) == 0:
+    if not augCanvas.ds.params:
         augCanvas.paramstable.setRowCount(0)
         return
-    elif len(augCanvas.ms['params'][0]) == augCanvas.paramstable.rowCount():
+    elif len(augCanvas.ds.params[0]) == augCanvas.paramstable.rowCount():
         states = [augCanvas.paramstable.cellWidget(row, 0).checkState()
                   for row in range(augCanvas.paramstable.rowCount())]
     else:
         states = False
-        augCanvas.paramstable.setRowCount(len(augCanvas.ms['params'][0]))
-    for row, paramname in enumerate(augCanvas.ms['params'][0]):
+        augCanvas.paramstable.setRowCount(len(augCanvas.ds.params[0]))
+    for row, paramname in enumerate(augCanvas.ds.params[0]):
         [augCanvas.paramstable.setItem(row, col, QtWidgets.QTableWidgetItem())
          for col in range(1, 3)]
         augCanvas.paramstable.setCellWidget(row, 0, QtWidgets.QCheckBox())
         if states:
             augCanvas.paramstable.cellWidget(row, 0).setCheckState(states[row])
         augCanvas.paramstable.item(row, 1).setText(paramname)
-        vals = [param[row] for param in augCanvas.ms['params'][1]
-                if (param[0] >= augCanvas.chrom['t_start'] and
-                param[0] <= augCanvas.chrom['t_end'])]
+        vals = [param[row] for param in augCanvas.ds.params[1]
+                if (param[0] >= augCanvas.ds.mintime and
+                param[0] <= augCanvas.ds.maxtime)]
         if len(vals) == 0:
             text = ""
         elif all([type(val) in [np.float32, np.float64] for val in vals]):
